==> trustai-0.1.0-py3-none-any.whl: trustai/evaluation/README.md <==
# 
ǴӺԺҳάȶģͽпɽ

<br>

## 
ģԤ֤˹ע֤ݵ϶ȣʹtoken-F1(macro-F1)set-F1(IoU-F1, Intersection over Union F1)Ϊָꡣ

ʽһ͹ʽ<br>
ʽһ
<p align="center">
<img align="center" src="../..//imgs/equation1.png", width=600><br>
</p>

ʽ
<p align="center">
<img align="center" src="../..//imgs/equation2.png", width=600><br>
</p>

 S<sub>i</sub><sup>p</sup>S<sub>i</sub><sup>g</sup>ֱԵiģԤ֤ݺ˹ע֤ݣNݼݵ<br>

<br><br>

## ҳ
ģṩ֤ݶ̶ϷӦģԤʱʵ̡ǴһԡԺ걸άģ͵ҳԡ

<br>

### һ
һ(ԭʼ룬ӦŶ)дҪһԡ֤ݷÿʸһҪȣڸҪȶдʽʹе**MAP**mean average precisionָһԡ¹ʽ
<br>

ʽ
<p align="center">
<img align="center" src="../..//imgs/equation3.png", width=600><br>
</p>

X<sup>o</sup>X<sup>p</sup>ֱԭʼŶĴҪС|X<sup>p</sup>|X<sup>p</sup>дʵĸX<sup>o</sup><sub>1:j</sub>ʾX<sup>o</sup>ǰjҪĴʡG(x, Y)xǷбYУG(x, Y)=1MAPԽ߱ʾһԽ

<br>

### Ժ걸
****ģ͸֤ǷԤҪȫϢ<br>
**걸**ģͶxԤ<br>
㷽ʽ£<br>
ʽ()
<p align="center">
<img align="center" src="../..//imgs/equation4.png", width=600><br>
</p>
ʽ(걸)

<p align="center">
<img align="center" src="../..//imgs/equation5.png", width=600><br>
</p>

F(x<sub>i</sub>)<sub>j</sub>ʾģFx<sub>i</sub>ԤΪlabel jĸʣr<sub>i</sub>ʾx<sub>i</sub>֤ݣӦأx<sub>i</sub>\r<sub>i</sub>ʾx<sub>i</sub>ķ֤ݲ֣r<sub>i</sub>x<sub>i</sub>ȥԵ÷Խ͡걸Ե÷Խߣʾ֤ݵҳԽߡ
<br>


## ʾ
```python
from trustai.evaluation import Evaluator

evaluator = Evaluator()

# goldensǻڲݱעı׼֤
# predictsǻڷõԤ֤
# ⣬ģԤ֤˹ע֤ݼϳ̶ȣѡtoken-F1(macro-F1)set-F1(IoU-F1, Intersection over Union F1)Ϊָꡣ
macro_f1 = evaluator.cal_f1(goldens, predicts)
iou_f1 = evaluator.calc_iou_f1(goldens, predicts)

# ҳ⣬ģ͸֤ݶ̶ӰԤ⡣ǴάӦ3ָ
# άһ֤ݵĳԺ걸ҳԣԱ֤ݰԤ㹻Ϣ걸Ա֤ݰ˶ԤӰϢ֤ݲ޷֧Ԥ⡣
sufficient, comprehensive = evaluator.cal_suf_com(goldens, predicts)
# άȶŶ֤ݵһԣƵ+Ƶ=Ƶ֤ݣһģҳϵ
map_score = evaluator.cal_map(goldens, predicts)
```
ʹʾ[tutorials](../../tutorials/evaluation/)

==> trustai-0.1.4-py3-none-any.whl: trustai/evaluation/README.md <==
# 
ǴӺԺҳάȶģͽпɽ

<br>

## 
ģԤ֤˹ע֤ݵ϶ȣʹtoken-F1(macro-F1)set-F1(IoU-F1, Intersection over Union F1)Ϊָꡣ

ʽһ͹ʽ<br>
ʽһ
<p align="center">
<img align="center" src="../..//imgs/equation1.png", width=600><br>
</p>

ʽ
<p align="center">
<img align="center" src="../..//imgs/equation2.png", width=600><br>
</p>

 S<sub>i</sub><sup>p</sup>S<sub>i</sub><sup>g</sup>ֱԵiģԤ֤ݺ˹ע֤ݣNݼݵ<br>

<br><br>

## ҳ
ģṩ֤ݶ̶ϷӦģԤʱʵ̡ǴһԡԺ걸άģ͵ҳԡ

<br>

### һ
һ(ԭʼ룬ӦŶ)дҪһԡ֤ݷÿʸһҪȣڸҪȶдʽʹе**MAP**mean average precisionָһԡ¹ʽ
<br>

ʽ
<p align="center">
<img align="center" src="../..//imgs/equation3.png", width=600><br>
</p>

X<sup>o</sup>X<sup>p</sup>ֱԭʼŶĴҪС|X<sup>p</sup>|X<sup>p</sup>дʵĸX<sup>o</sup><sub>1:j</sub>ʾX<sup>o</sup>ǰjҪĴʡG(x, Y)xǷбYУG(x, Y)=1MAPԽ߱ʾһԽ

<br>

### Ժ걸
****ģ͸֤ǷԤҪȫϢ<br>
**걸**ģͶxԤ<br>
㷽ʽ£<br>
ʽ()
<p align="center">
<img align="center" src="../..//imgs/equation4.png", width=600><br>
</p>
ʽ(걸)

<p align="center">
<img align="center" src="../..//imgs/equation5.png", width=600><br>
</p>

F(x<sub>i</sub>)<sub>j</sub>ʾģFx<sub>i</sub>ԤΪlabel jĸʣr<sub>i</sub>ʾx<sub>i</sub>֤ݣӦأx<sub>i</sub>\r<sub>i</sub>ʾx<sub>i</sub>ķ֤ݲ֣r<sub>i</sub>x<sub>i</sub>ȥԵ÷Խ͡걸Ե÷Խߣʾ֤ݵҳԽߡ
<br>


## ʾ
```python
from trustai.evaluation import Evaluator

evaluator = Evaluator()

# goldensǻڲݱעı׼֤
# predictsǻڷõԤ֤
# ⣬ģԤ֤˹ע֤ݼϳ̶ȣѡtoken-F1(macro-F1)set-F1(IoU-F1, Intersection over Union F1)Ϊָꡣ
macro_f1 = evaluator.cal_f1(goldens, predicts)
iou_f1 = evaluator.calc_iou_f1(goldens, predicts)

# ҳ⣬ģ͸֤ݶ̶ӰԤ⡣ǴάӦ3ָ
# άһ֤ݵĳԺ걸ҳԣԱ֤ݰԤ㹻Ϣ걸Ա֤ݰ˶ԤӰϢ֤ݲ޷֧Ԥ⡣
sufficency, comprehensiveness = evaluator.cal_suf_com(goldens, predicts)
# άȶŶ֤ݵһԣƵ+Ƶ=Ƶ֤ݣһģҳϵ
map_score = evaluator.cal_map(goldens, predicts)
```
ʹʾ[tutorials](../../tutorials/evaluation/)
